@@ -26,7 +26,7 @@ except NameError: # pragma no cover
     _unicode = str
 
 __author__ = 'Martin Blech'
-__version__ = '0.4.6'
+__version__ = '0.5.0'
 __license__ = 'MIT'
 
 class ParsingInterrupted(Exception): pass
@@ -121,7 +121,7 @@ class _DictSAXHandler(object):
             item[key] = data
         return item
 
-def parse(xml_input, encoding='utf-8', *args, **kwargs):
+def parse(xml_input, encoding='utf-8', expat=expat, *args, **kwargs):
     """Parse the given XML input and convert it into a dictionary.
 
     `xml_input` can either be a `string` or a file-like object.
@@ -180,6 +180,13 @@ def parse(xml_input, encoding='utf-8', *args, **kwargs):
         ...                 postprocessor=postprocessor)
         OrderedDict([(u'a', OrderedDict([(u'b:int', [1, 2]), (u'b', u'x')]))])
 
+    You can pass an alternate version of `expat` (such as `defusedexpat`) by
+    using the `expat` parameter. E.g:
+
+        >>> import defusedexpat
+        >>> xmltodict.parse('<a>hello</a>', expat=defusedexpat.pyexpat)
+        OrderedDict([(u'a', u'hello')])
+
     """
     handler = _DictSAXHandler(*args, **kwargs)
     parser = expat.ParserCreate()
